; NAME: 
;      PHOT_RESULTS
; 
; VERSION: 1
; 
; PURPOSE: 
;      Reads output of aperture photometry programs at selected 
;      aperture and creates an output file for a nights run.
; 
; CALLING SEQUENCE: 
;      phot_results, infiles, outfile, aper, [path=path, amc=amc, 
;                    help=help]
; 
; INPUTS: 
;      infiles - String vector of input filenames 
;      outfile - Filename of output file
;      aper - Aperture size in pixels
; 
; OPTIONAL KEYWORD INPUTS: 
;      path - Paths for infiles and outfile
;      amc - Set to correct instrumental magnitude for airmass
;      help - Set to nonzero scalar to print syntax
; 
; OUTPUT: 
;      Observer, instrument, location, observation date, and aperture
;      are saved.  This is followed by a table of object name, airmass,
;      counts/second, counts/second error, instrumental magnitude, and 
;      instrumental magnitude error.
; 
; EXTERNAL CALLS: 
;      FILEX
; 
; COMMON BLOCKS: 
;      NONE
; 
; MODIFICATION HISTORY: 
;      - Written by Eric Volquardsen, NASA IRTF, October 2003
; 
; =======================================================================
PRO phot_results, infiles, outfile, aper, path=path, amc=amc, help=help

; CHECK INPUTS
     IF n_elements(help) EQ 1 THEN BEGIN
          IF help NE 0 THEN help = 1 
     ENDIF ELSE help = 0 
     nf = n_elements(infiles)
     IF nf LT 1 THEN help = 1 
     IF n_elements(outfile) NE 1 THEN help = 1 
     IF n_elements(aper) NE 1 THEN help = 1 
     IF help EQ 1 THEN BEGIN
          print, '***************************************************'
          print, '***             PHOT_RESULTS SYNTAX             ***'  
          print, '*** IDL> phot_results, infiles, outfile, aper,  ***' 
          print, '***                    path=path, amc=amc       ***' 
          print, '***                                             ***' 
          print, '*** infiles - String vector of input filenames  ***' 
          print, '*** outfile - Filename of output file           ***' 
          print, '*** aper - Aperture size in pixels              ***' 
          print, '*** path - Paths for infiles and outfile        ***' 
          print, '*** amc - Set to correct instrumental magnitude ***' 
          print, '***       for airmass [zero point, extinction]  ***' 
          print, '***************************************************'   
          RETURN
     ENDIF
     np = n_elements(path)
     CASE np OF 
          0 : BEGIN
               v = !version.os_family
               CASE v OF
                    'vms' : root = '[]'
                    'windows' : root = 'c:\'
                    ELSE : root = '/'
                ENDCASE
                cd, root, current=pat
                cd, pat
                path = [pat, pat]
          END
          1 : path = [path, path]
          ELSE : path = path[0:1]
     ENDCASE

; INITALIZE VALUES FROM FIRST INPUT FILE
     data1 = strarr(20)
     chk = FILEX(infiles[0], path[0])
     IF chk EQ 0 THEN BEGIN
          print, infiles[0], ' DOES NOT EXIST'
          RETURN
     ENDIF
     cd, path[0], current=nowp
     openr, logun, infiles[0], /get_lun
     readf, logun, data1
     inst = strsplit(data1[1], /extract)
     IF n_elements(inst) GT 1 THEN inst = inst[1] ELSE inst = ''
     IF inst EQ 'Apogee' THEN skp = 20 ELSE skp = 21
     obs = strtrim(strmid(data1[0], 9), 2)
     loc = strtrim(strmid(data1[2], 9), 2)
     odt = strtrim(strmid(data1[5], 19), 2)
     sr1 = strsplit(data1[skp-12], /extract)
     sr1 = sr1[3]
     sr2 = strsplit(data1[skp-11], /extract)
     sr2 = sr2[3]
     sr = sr1 + ' to ' + sr2 + ' pixels'
     free_lun, logun

; CREATE TABLE
     ss = 0 
     f = 'a,a,a,a,a,a'
     table = strarr(6,nf)
     table[1:5, *] = '0'
     FOR i = 0, (nf-1) DO BEGIN
          nofile: 
          chk = FILEX(infiles[i], path[0])
          IF chk EQ 0 THEN BEGIN 
               print, infiles[i], ' DOES NOT EXIST'
               i = i + 1 
               IF i LE (nf-1) THEN GOTO, nofile ELSE GOTO, nofile2
          ENDIF
          IF skp EQ 21 THEN BEGIN
               openr, logun, infiles[i], /get_lun
               readf, logun, data1
               free_lun, logun 
               table[1, i] = strtrim(strmid(data1[8], 19), 2)
          ENDIF
          fst = strpos(infiles[i], '.')
          IF fst GT 0 THEN table[0,i] = strmid(infiles[i], 0, fst) $ 
               ELSE table[0,i] = infiles[i]
          READCOL, infiles[i], ar, ap, cs, cse, im, ime, format=f, $ 
                   skipline=skp
          w = where(float(ar) EQ aper)
          IF w EQ -1 THEN BEGIN
               print, infiles[i], ' DOES NOT HAVE APERTURE ', string(aper)
               i = i + 1 
               IF i LE (nf-1) THEN GOTO, nofile ELSE GOTO, nofile2
          ENDIF       
          table[2, i] = cs[w]
          table[3, i] = cse[w]
          table[4, i] = im[w]
          table[5, i] = ime[w]
          s = strlen(table[0, i])
          IF s GT ss THEN ss = s 
     ENDFOR
     nofile2: 

; CORRECT FOR AIRMASS (if set)
     IF n_elements(amc) EQ 1 THEN BEGIN
          IF amc[0] NE 0 THEN BEGIN
               t1 = float(table[1,*])
               t4 = float(table[4,*])
               ww = where(t1 GE 1)
               table[4,ww] = string(t4[ww] - (t1[ww]-1)*0.1)
               table[4,*] = strtrim(table[4,*], 2)
          ENDIF
     ENDIF ELSE BEGIN
          IF n_elements(amc) GE 2 THEN BEGIN
               t1 = float(table[1,*])
               t4 = float(table[4,*])
               ww = where(t1 GE 1)
               table[4,ww] = string(t4[ww] - t1[ww]*amc[1] - amc[0])
               table[4,*] = strtrim(table[4,*], 2)
          ENDIF
     ENDELSE

; SAVE RESULTS
     l1 = 'OBSERVER:     '
     l2 = 'INSTRUMENT:   '
     l3 = 'LOCATION:     '
     l4 = 'DATE:         '
     l5 = 'APERTURE:     '
     l6 = 'SKY RADII:    '
     tbl0 = '   Object    Airmass    CTS/sec      Error   Magnitude    Error'
     tbl1 = '|----------|----------|----------|' + $ 
            '----------|---------|----------|'
     cd, path[1]
     openw, logun, outfile, /get_lun
     printf, logun, '  '
     printf, logun, l1, obs
     printf, logun, l2, inst
     printf, logun, l3, loc
     printf, logun, l4, odt
     printf, logun, l5, strtrim(string(aper), 2)
     printf, logun, l6, sr
     printf, logun, '   '
     printf, logun, tbl0
     printf, logun, tbl1
     IF skp EQ 20 THEN spc = '          ' ELSE spc = '   '
     nct = max(strlen(table[2, *]))
     FOR j = 0, (nf-1) DO BEGIN 
          s = ss - strlen(table[0,j])
          CASE s OF 
               0 : spc1 = ' '
               1 : spc1 = '  '
               2 : spc1 = '   '
               3 : spc1 = '    '
               4 : spc1 = '     '
               ELSE : spc1 = '      '
          ENDCASE
          nc = nct - strlen(table[2, j])
          CASE nc OF 
               0 : nc1 = ' '
               1 : nc1 = '  '
               2 : nc1 = '   '
               3 : nc1 = '    '
               4 : NC1 = '     '
               ELSE : nc1 = '      '
          ENDCASE
          line = spc1 + table[0,j] + spc + table[1,j] + nc1 + $ 
                 spc + table[2,j] + '       ' + table[3,j] + $ 
                 '      '  + table[4,j] + '   ' + table[5,j]
          printf, logun, line
     ENDFOR 
     free_lun, logun
     cd, nowp
END
